
# Slot: process positively regulated by process




URI: [biolink:process_positively_regulated_by_process](https://w3id.org/biolink/vocab/process_positively_regulated_by_process)


## Domain and Range

[Occurrent](Occurrent.md) &#8594;  <sub>0..\*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [process regulated by process](process_regulated_by_process.md)

## Children


## Used by

